==> usermanager-1.0.8.tgz: package/README.md <==

ag-Grid
==============

#### Install with Bower
```sh
$ bower install ag-grid
```

#### Install with Npm
```sh
$ npm install ag-grid
```

See the [www.ag-grid.com](http://www.ag-grid.com) for overview and documentation.


Building
==============

To build:
- `npm install`
- `npm install gulp -g`
- `bower install`
- `gulp` or `gulp release`

Normal 'gulp' does not include minification or source maps, and starts a watch. This is for development.

'gulp release' does minification and no source maps. This is for releasing.

If you are doing a Pull Request:
- Make your code changes in `src/` files only, don't update dist files
- Make your doc changes in `docs/`, a feature is not complete unless it's documented
- Do manual end to end testing off all examples in documentation
- Discard all changes to `dist/`
- Create Pull Request

Asking Questions
==============

Please do not use GitHub issues to ask questions. Ask questions on the
[website forum](http://www.ag-grid.com/forum).


Contributing
==============

I am not looking for contributors for this project. If you have ideas, feel free to
get in touch and let me know. Or if you want to suggest something, feel free to
create a pull request with your ideas.

My reason for not looking for contributors is that this grid is my hobby,
something I work on in my spare time and enjoy. The design is something of a passion,
and I'm bringing the grid into a particular direction. To take on contributors
would require overhead of organisation, as well as agreeing direction (both
technical implementation and functional requirements).

If you would like to help, then please provide me with guidance and advice.
I don't claim to know everything, so welcome others opinions on the direction
of the project.

==> usermanager-2.0.2.tgz: package/README.md <==

user manager
==============

#### Install with Bower
```sh
$ bower install ag-grid
```

#### Install with Npm
```sh
$ npm install ag-grid
```

See the [www.demo.quant-edge.com](https://demo.quant-edge.com) for overview and documentation.


Building
==============

To build:
- `npm install`
- `npm install gulp -g`
- `bower install`
- `gulp` or `gulp release`

Normal 'gulp' does not include minification or source maps, and starts a watch. This is for development.

'gulp release' does minification and no source maps. This is for releasing.

If you are doing a Pull Request:
- Make your code changes in `src/` files only, don't update dist files
- Make your doc changes in `docs/`, a feature is not complete unless it's documented
- Do manual end to end testing off all examples in documentation
- Discard all changes to `dist/`
- Create Pull Request

Asking Questions
==============


Contributing
==============

I am not looking for contributors for this project. If you have ideas, feel free to
get in touch and let me know. Or if you want to suggest something, feel free to
create a pull request with your ideas.

My reason for not looking for contributors is that this grid is my hobby,
something I work on in my spare time and enjoy. The design is something of a passion,
and I'm bringing the grid into a particular direction. To take on contributors
would require overhead of organisation, as well as agreeing direction (both
technical implementation and functional requirements).

If you would like to help, then please provide me with guidance and advice.
I don't claim to know everything, so welcome others opinions on the direction
of the project.
